% INTERPOLATING U, V, T & S FIELDS FROM S TO Z COORDINATES
%
% Adapted from the original program "plot_roms.m"
% by Ricardo M. Domingues, 15/04/2010
%
%
% SAVING THE OUTPUT FIELDS TO ".mat" files
%
% saving only U & V fields
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc
clear all
close all

ofile = input(' - Enter the model output filename >>','s');
disp(' ')
gfile = input(' - Enter the model grid filename >>','s');
disp(' ')
DAY = input(' - Enter the output period of interest>>');

dir_out = '/data2/IEAPM/Ricardo/ROMS/MAT/';

%gfile = input(' - Enter the maximum depth desired >>','s');

dz = 0.5; % Z interpolation interval
max_depth = 20;max_depth=-1*max_depth;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% GETTING GRID INFORMATION

ncg = netcdf(gfile);
lon   = ncg{'lon_rho'}(:);
lat   = ncg{'lat_rho'}(:);
lonu  = ncg{'lon_u'}(:);
latu  = ncg{'lat_u'}(:);
lonv  = ncg{'lon_v'}(:);
latv  = ncg{'lat_v'}(:);
h     = ncg{'h'}(:);
[im,jm] = size(h);

save([dir_out,'longitude'],'lon')
save([dir_out,'latitude'],'lat')
%==========================================================================


for day = DAY; % begining of the horizontal plots

    dd=num2str(day);
    
    % ---------------------------------------------------------------------------------

    % reading and preparing the output variables --------------------------------------
    
    nci = netcdf(ofile);
    t   =  nci{'temp'}(day,:,:,:);
    s   =  nci{'salt'}(day,:,:,:);
    u   =  nci{'u'}(day,:,:,:);
    v   =  nci{'v'}(day,:,:,:);
    
    TETA =  nci{'angle'}(:,:);
    Cont = find(t==0);s(Cont)=nan;t(Cont)=nan;
    % Girando os vetores para plotar no GMT--------------------------------
    
    for depth=1:25
        depth
        uu  =  squeeze(u(depth,:,:));
        vv  =  squeeze(v(depth,:,:));

        [X,Y,U_a] = griddata(lonu,latu,uu,lon,lat);
        [X,Y,V_a] = griddata(lonv,latv,vv,lon,lat);          


        UU=U_a.*cos(TETA)-V_a.*sin(TETA);
        VV=U_a.*sin(TETA)+V_a.*cos(TETA);
              
        U(depth,:,:)=UU; V(depth,:,:)=VV;
    end
    
    U(Cont)=nan;V(Cont)=nan;
    
    clear UU VV U_a V_a;

    %======================================================================
    % Sigma to Z
    
      disp('   ')
      disp('Getting depths of S levels .......')
      disp('   ')

      [km,im,jm] = size(t);      
      zt = get_depths(ofile,gfile,1,'t');
      zs = get_depths(ofile,gfile,1,'s');
      zu = get_depths(ofile,gfile,1,'U');
      zv = get_depths(ofile,gfile,1,'V');
      z=zt;
      
      if(isempty(max_depth)==1)
          imaxt=ones(im,jm);imaxs=ones(im,jm);
          imaxu=ones(im,jm);imaxv=ones(im,jm);
      else
          for a=1:im
              for b=1:jm

                  maxt=find(zt(:,a,b)>=max_depth);maxt=maxt(1);
                  maxs=find(zs(:,a,b)>=max_depth);maxs=maxs(1);
                  maxu=find(zu(:,a,b)>=max_depth);maxu=maxu(1);
                  maxv=find(zv(:,a,b)>=max_depth);maxv=maxv(1);

                  imaxt(a,b)=maxt;imaxs(a,b)=maxs;
                  imaxu(a,b)=maxu;imaxv(a,b)=maxv;

              end
          end
      end
              

      zi = 0:dz:-1*max_depth;zi=-1*zi';
      
      disp('   ')
      disp('Interpolating from S to Z coordinate system .......')
      disp('   ')

         auxt = []; auxs = [];
         for a = 1:im
         for b = 1:jm
             
            auxt = interp1(zt(imaxt(a,b):25,a,b),t(imaxt(a,b):25,a,b),zi);
            auxs = interp1(zs(imaxs(a,b):25,a,b),s(imaxs(a,b):25,a,b),zi);
            auxu = interp1(zu(imaxu(a,b):25,a,b),U(imaxu(a,b):25,a,b),zi);
            auxv = interp1(zv(imaxv(a,b):25,a,b),V(imaxv(a,b):25,a,b),zi);
            
            tz(:,a,b) = auxt;
            sz(:,a,b) = auxs;
            uz(:,a,b) = auxu;
            vz(:,a,b) = auxv;
         end
         end
         
    u=squeeze(uz(21,:,:));v=squeeze(vz(21,:,:));
    save([dir_out,ofile(1:end-3),'_',sprintf('%04g',day)],'u','v')
         
end
   

